//// -------------------------------------------------------------------------
//// File     : DDCHTEXT.DCL
//// Copyright: cad nauseam, 1996.  Shareware: see DDCHTEXT.TXT for details.
//// Author   : Steve Johnson
//// Purpose  : Dialogue box definition for DDCHTEXT command.
//// Version  : 1.0
//// Date     : 4 March 1996
//// -------------------------------------------------------------------------


/// --------------------------------------------------------------------------
/// Turn off error checking
/// --------------------------------------------------------------------------

dcl_settings : default_dcl_settings { audit_level = 0; }


/// --------------------------------------------------------------------------
/// Widget: ddchtext
/// This is the main DDCHTEXT dialogue box.
/// --------------------------------------------------------------------------

ddchtext : dialog {
  label                 = "DDCHTEXT";
  entity_set;
  : row {
    properties_set;
    attrib_set;
  }
  settings_set;
  search_set;
  spacer;
  finish_buttons;
  errtile;
}


/// --------------------------------------------------------------------------
/// Widget: entity_set
/// Radio column to allow user to choose entity type to change.
/// --------------------------------------------------------------------------

entity_set : boxed_row {
  label                 = "Entity types to change";
  key                   = "entity";
  : toggle {
    key                 = "text";
    label               = "Text";
  }
  : toggle {
    key                 = "mtext";
    label               = "Mtext";
  }
  : toggle {
    key                 = "attdef";
    label               = "Attdef";
  }
  : toggle {
    key                 = "attrib";
    label               = "Attribute";
  }
}


/// --------------------------------------------------------------------------
/// Widget: properties_set
/// Column containing widgets for layer and color settings.
/// --------------------------------------------------------------------------

properties_set : boxed_column {
  label                 = "Properties";
  layr_set;
  color_set;
}


/// --------------------------------------------------------------------------
/// Widget: attrib_set
/// Boxed column with edit boxes for block and tag names/wildcards.
/// --------------------------------------------------------------------------

attrib_set : boxed_column {
  key                   = "attrib_area";
  label                 = "Attribute filters";
  : ddch_mid_edit {
    key                 = "block";
    label               = "Block name:";
  }
  : ddch_mid_edit {
    key                 = "tag";
    label               = "Tag name:";
  }
}


/// --------------------------------------------------------------------------
/// Widget: settings_set
/// Column containing widgets for most text settings.
/// --------------------------------------------------------------------------

settings_set : boxed_column {
  label                 = "Settings";
  height_set;
  width_set;
  mtextwidth_set;
  rotation_set;
  oblique_set;
  justify_set;
  style_set;
}


/// --------------------------------------------------------------------------
/// Widget: search_set
/// Toggle-controlled row with edit boxes for search and replace text
/// and toggle for case-sensitivity.
/// --------------------------------------------------------------------------

search_set : boxed_row {
  label                 = "Search and replace";
  : column {
    spacer;
    : toggle {
      key               = "search_toggle";
      label             = "Replace:";
    }
    spacer;
  }
  : row {
    key                 = "search_area";
    fixed_width         = true;
    : column {
      : text {
        label           = "This text:";
      }
      : text {
        label           = "With this:";
      }
    }
    : column {
      : row {
        : ddch_big_edit {
          label         = "";
          key           = "search";
        }
      }
      : row {
        : ddch_big_edit {
          label         = "";
          key           = "replace";
        }
      }
    }
    : column {
      spacer;
      : toggle {
        label           = "Case sensitive";
        key             = "case";
        is_enabled      = false;
      }
      spacer;
    }
  }
}


/// --------------------------------------------------------------------------
/// Widget: finish_buttons
/// Row of buttons at bottom of dialogue.
/// --------------------------------------------------------------------------

finish_buttons : column {
  : row {
    fixed_width         = true;
    alignment           = centered;
    select_button;
    : spacer {width     = 2; }
    all_button;
    : spacer {width     = 2; }
    cancel_button;
  }
}


/// --------------------------------------------------------------------------
/// Widget: layr_set
/// Toggle-controlled row with button and edit box for text layer.
/// --------------------------------------------------------------------------

layr_set : ddch_set {
  fixed_width           = true;
  children_fixed_width  = true;
  : toggle {
    key                 = "layr_toggle";
    label               = "Layer:";
    width               = 10;
    fixed_width         = true;
  }
  : row {
    key                 = "layr_area";
    : ddch_button {
      label             = "Layer...";
      key               = "layr_button";
    }
    : ddch_mid_edit {
      key               = "layr";
    }
  }
}


/// --------------------------------------------------------------------------
/// Widget: color_set
/// Toggle-controlled row with button and edit box for text color.
/// --------------------------------------------------------------------------

color_set : ddch_set {
  fixed_width           = true;
  children_fixed_width  = true;
  : toggle {
    key                 = "color_toggle";
    label               = "Color:";
    width               = 10;
  }
  : row {
    key                 = "color_area";
    : ddch_button {
      label             = "Color...";
      key               = "color_button";
    }
    : ddch_mid_edit {
      key               = "color";
    }
  }
}


/// --------------------------------------------------------------------------
/// Widget: height_set
/// Toggle-controlled row with edit box for text height.
/// --------------------------------------------------------------------------

height_set : ddch_set {
  : ddch_toggle {
    key                 = "height_toggle";
    label               = "Height:";
  }
  : row {
    key                 = "height_area";
    : ddch_edit {
      key               = "height";
    }
  }
  : toggle {
    key                 = "height_relative";
    label               = "x Current";
    is_enabled          = false;
  }
}


/// --------------------------------------------------------------------------
/// Widget: rotation_set
/// Toggle-controlled row with edit box for text rotation angle.
/// --------------------------------------------------------------------------

rotation_set : ddch_set {
  : ddch_toggle {
    key                 = "rotation_toggle";
    label               = "Rotation angle:";
  }
  : row {
    key                 = "rotation_area";
    : ddch_edit {
      key               = "rotation";
    }
  }
  : toggle {
    key                 = "rotation_relative";
    label               = "+ Current";
    is_enabled          = false;
  }
}


/// --------------------------------------------------------------------------
/// Widget: width_set
/// Toggle-controlled row with edit box for text width.
/// --------------------------------------------------------------------------

width_set : ddch_set {
  : ddch_toggle {
    key                 = "width_toggle";
    label               = "Width factor:";
  }
  : row {
    key                 = "width_area";
    : ddch_edit {
      key               = "width";
    }
  }
  : toggle {
    key                 = "width_relative";
    label               = "x Current";
    is_enabled          = false;
  }
}


/// --------------------------------------------------------------------------
/// Widget: mtextwidth_set
/// Toggle-controlled row with edit box for mtext width.
/// --------------------------------------------------------------------------

mtextwidth_set : ddch_set {
  : ddch_toggle {
    key                 = "mtextwidth_toggle";
    label               = "Mtext width:";
  }
  : row {
    key                 = "mtextwidth_area";
    : ddch_edit {
      key               = "mtextwidth";
    }
  }
  : toggle {
    key                 = "mtextwidth_relative";
    label               = "x Current";
    is_enabled          = false;
  }
}


/// --------------------------------------------------------------------------
/// Widget: oblique_set
/// Toggle-controlled row with edit box for text obliqueing angle.
/// --------------------------------------------------------------------------

oblique_set : ddch_set {
  : ddch_toggle {
    key                 = "oblique_toggle";
    label               = "Obliquing angle:";
  }
  : row {
    key                 = "oblique_area";
    : ddch_edit {
      key               = "oblique";
    }
  }
  : toggle {
    key                 = "oblique_relative";
    label               = "+ Current";
    is_enabled          = false;
  }
}


/// --------------------------------------------------------------------------
/// Widget: justify_set
/// Toggle-controlled row with popup list box for text justification.
/// --------------------------------------------------------------------------

justify_set : ddch_set {
  : ddch_toggle {
    key                 = "justify_toggle";
    label               = "Justification:";
  }
  : row {
    key                 = "justify_area";
    : ddch_popup {
      key               = "justify";
    }
  }
}


/// --------------------------------------------------------------------------
/// Widget: style_set
/// Toggle-controlled row with popup list box for text style.
/// --------------------------------------------------------------------------

style_set : ddch_set {
  : ddch_toggle {
    key                 = "style_toggle";
    label               = "Style:";
  }
  : row {
    key                 = "style_area";
    : ddch_popup {
      key               = "style";
    }
  }
}


/// --------------------------------------------------------------------------
/// Widget: select_button
/// Retirement button marked "Select".
/// --------------------------------------------------------------------------

select_button : retirement_button {
  label                 = "Select";
  key                   = "select_ok";
  is_default            = true;
}


/// --------------------------------------------------------------------------
/// Widget: all_button
/// Retirement button marked "All".
/// --------------------------------------------------------------------------

all_button : retirement_button {
  label                 = "All";
  key                   = "all_ok";
}


/// --------------------------------------------------------------------------
/// Widget: ddch_set
/// General row definition for toggle-controlled rows.
/// --------------------------------------------------------------------------

ddch_set : row {
  fixed_width           = true;
  is_enabled            = false;
}


/// --------------------------------------------------------------------------
/// Widget: ddch_toggle
/// General toggle definition for toggle-controlled rows.
/// --------------------------------------------------------------------------

ddch_toggle : toggle {
  width                 = 20;
}


/// --------------------------------------------------------------------------
/// Widget: ddch_edit
/// General small edit box definition.
/// --------------------------------------------------------------------------

ddch_edit : edit_box {
  edit_width            = 15;
  is_enabled            = false;
}


/// --------------------------------------------------------------------------
/// Widget: ddch_mid_edit
/// General large edit box definition.
/// --------------------------------------------------------------------------

ddch_mid_edit : edit_box {
  edit_width            = 15;
  is_enabled            = false;
}


/// --------------------------------------------------------------------------
/// Widget: ddch_big_edit
/// General large edit box definition.
/// --------------------------------------------------------------------------

ddch_big_edit : edit_box {
  edit_width            = 30;
  is_enabled            = false;
  fixed_width           = true;
}


/// --------------------------------------------------------------------------
/// Widget: ddch_button
/// General button definition.
/// ------------------------------------------------------------------

ddch_button : button {
  width                 = 12;
  fixed_width           = true;
  is_enabled            = false;
}


/// ------------------------------------------------------------------
/// Widget: ddch_popup
/// General popup list definition.
/// --------------------------------------------------------------------------

ddch_popup : popup_list {
  edit_width            = 31;
  fixed_width           = true;
  is_enabled            = false;
}


/// --------------------------------------------------------------------------
/// Widget: list_layers
/// This is a sub dialogue box used to list the currently attached
/// XREFs and allow the user to select one.
/// --------------------------------------------------------------------------

list_layers : dialog {
  label                 = "Layers";
  : list_box {
    key                 = "list_box";
    width               = 31;
  }
  spacer;
  ok_cancel_err;
}


/// --------------------------------------------------------------------------
/// End DDCHTEXT.DCL
/// --------------------------------------------------------------------------